# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/violation.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'eolymp/judge/violation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/judge/violation.proto\x12\x0c\x65olymp.judge\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf4\x01\n\tViolation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tcancelled\x18\x02 \x01(\x08\x12\x0f\n\x07summary\x18\x03 \x01(\t\x12\x11\n\tautomatic\x18\x04 \x01(\x08\x12\x16\n\x0eparticipant_id\x18\x05 \x01(\t\x12\x10\n\x08given_by\x18\n \x01(\t\x12,\n\x08given_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1aL\n\x05Patch\"C\n\x05\x46ield\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07SUMMARY\x10\x01\x12\r\n\tCANCELLED\x10\x02\x12\r\n\tAUTOMATIC\x10\x03\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.violation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_VIOLATION']._serialized_start=80
  _globals['_VIOLATION']._serialized_end=324
  _globals['_VIOLATION_PATCH']._serialized_start=248
  _globals['_VIOLATION_PATCH']._serialized_end=324
  _globals['_VIOLATION_PATCH_FIELD']._serialized_start=257
  _globals['_VIOLATION_PATCH_FIELD']._serialized_end=324
# @@protoc_insertion_point(module_scope)
